Network Attack Simulator
========================

|docs|

Network Attack Simulator (NASim) is a simulated computer network complete with vulnerabilities, scans and exploits designed to be used as a testing environment for AI agents and planning techniques applied to network penetration testing.

**Note**: NASim is currently under active development so there will be small changes still occuring that may affect some functionallity. However, I'm hoping for a stable release soon.


Documentation
-------------

The documentation is available at: https://networkattacksimulator.readthedocs.io/

Authors
-------

**Jonathon Schwartz** - Jonathon.schwartz@anu.edu.au

.. |docs| image:: https://readthedocs.org/projects/networkattacksimulator/badge/?version=latest
    :target: https://networkattacksimulator.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
    :scale: 100%

License
-------

`MIT`_ © 2020, Jonathon Schwartz

.. _MIT: LICENSE
